<?php

namespace Bixo\Location\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Bixo\Location\Http\Requests\SublocationRequest;
use Bixo\Location\Interfaces\SublocationRepositoryInterface;
use Bixo\Location\Models\Sublocation;
use Bixo\Location\Forms\Sublocation as Form;

/**
 * APIController  class for sublocation.
 */
class SublocationAPIController extends BaseController
{

    /**
     * Initialize sublocation resource controller.
     *
     * @param type SublocationRepositoryInterface $sublocation
     *
     * @return null
     */
    public function __construct(SublocationRepositoryInterface $sublocation)
    {
        parent::__construct();
        $this->repository = $sublocation;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Bixo\Location\Repositories\Criteria\SublocationResourceCriteria::class);
    }

    /**
     * Display a list of sublocation.
     *
     * @return Response
     */
    public function index(SublocationRequest $request)
    {
        return $this->repository
            ->setPresenter(\Bixo\Location\Repositories\Presenter\SublocationPresenter::class)
            ->paginate();
    }

    /**
     * Display sublocation.
     *
     * @param Request $request
     * @param Model   $sublocation
     *
     * @return Response
     */
    public function show(SublocationRequest $request, Sublocation $sublocation)
    {
        return $sublocation->setPresenter(\Bixo\Location\Repositories\Presenter\SublocationListPresenter::class);
        ;
    }

    /**
     * Create new sublocation.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(SublocationRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('location::sublocation.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('location/sublocation/' . $sublocation->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('location/sublocation');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the sublocation.
     *
     * @param Request $request
     * @param Model   $sublocation
     *
     * @return Response
     */
    public function update(SublocationRequest $request, Sublocation $sublocation)
    {
        try {
            $data = $request->all();

            $sublocation->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('location::sublocation.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('location/sublocation/' . $sublocation->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('location/sublocation/' . $sublocation->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the sublocation.
     *
     * @param Model   $sublocation
     *
     * @return Response
     */
    public function destroy(SublocationRequest $request, Sublocation $sublocation)
    {
        try {
            $sublocation->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('location::sublocation.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('location/sublocation/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('location/sublocation/' . $sublocation->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
